@@ -5,7 +5,7 @@
 #
 # Various non-GUI helper functions for Biblelator Bible display/editing
 #
-# Copyright (C) 2014-2018 Robert Hunt
+# Copyright (C) 2014-2020 Robert Hunt
 # Author: Robert Hunt <Freely.Given.org+Biblelator@gmail.com>
 # License: See gpl-3.0.txt
 #
@@ -24,7 +24,7 @@
 
 """
     createEmptyUSFMBookText( BBB, getNumChapters, getNumVerses )
-    createEmptyUSFMBooks( folderPath, BBB, availableVersifications, availableVersions, requestDict )
+    createEmptyUSFMBooks( folderpath, BBB, availableVersifications, availableVersions, requestDict )
     calculateTotalVersesForBook( BBB, getNumChapters, getNumVerses )
     mapReferenceVerseKey( mainVerseKey )
     mapParallelVerseKey( forGroupCode, mainVerseKey )
@@ -34,25 +34,11 @@
 
 TODO: Can some of these non-GUI functions be (made more general and) moved to the BOS?
 """
-
 from gettext import gettext as _
-
-LAST_MODIFIED_DATE = '2018-04-24' # by RJH
-SHORT_PROGRAM_NAME = "BiblelatorHelpers"
-PROGRAM_NAME = "Biblelator helpers"
-PROGRAM_VERSION = '0.46'
-programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
-
-debuggingThisModule = False
-
-
 import os.path
 from datetime import datetime
 import re
 
-# Biblelator imports
-from Biblelator.BiblelatorGlobals import APP_NAME_VERSION, BIBLE_GROUP_CODES
-
 # BibleOrgSys imports
 from BibleOrgSys import BibleOrgSysGlobals
 from BibleOrgSys.BibleOrgSysGlobals import vPrint
@@ -61,6 +47,23 @@ from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey, BBB_RE #, Flex
 from BibleOrgSys.Reference.BibleReferencesLinks import BibleReferencesLinks
 from BibleOrgSys.Internals.InternalBibleInternals import InternalBibleEntry
 
+# Biblelator imports
+if __name__ == '__main__':
+    import sys
+    aboveAboveFolderPath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderPath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderPath )
+from Biblelator.BiblelatorGlobals import APP_NAME_VERSION, BIBLE_GROUP_CODES
+
+
+LAST_MODIFIED_DATE = '2020-04-26' # by RJH
+SHORT_PROGRAM_NAME = "BiblelatorHelpers"
+PROGRAM_NAME = "Biblelator helpers"
+PROGRAM_VERSION = '0.46'
+programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
+
+debuggingThisModule = False
+
 
 
 def createEmptyUSFMBookText( BBB, getNumChapters, getNumVerses ):
@@ -69,7 +72,7 @@ def createEmptyUSFMBookText( BBB, getNumChapters, getNumVerses ):
     Returns a string that is the text of a blank USFM book.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "createEmptyUSFMBookText( {} )".format( BBB ) )
+        vPrint( 'Quiet', debuggingThisModule, "createEmptyUSFMBookText( {} )".format( BBB ) )
 
     USFMAbbreviation = BibleOrgSysGlobals.loadedBibleBooksCodes.getUSFMAbbreviation( BBB )
     USFMNumber = BibleOrgSysGlobals.loadedBibleBooksCodes.getUSFMNumber( BBB )
@@ -89,9 +92,9 @@ def createEmptyUSFMBookText( BBB, getNumChapters, getNumVerses ):
 
 
 
-def createEmptyUSFMBooks( folderPath, currentBBB, requestDict ):
+def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
     """
-    Create empty USFM books or CV shells in the given folderPath
+    Create empty USFM books or CV shells in the given folderpath
         as requested by the dictionary parameters:
             Books: 'OT'
             Fill: 'Versification'
@@ -104,23 +107,23 @@ def createEmptyUSFMBooks( folderPath, currentBBB, requestDict ):
     from BibleOrgSys.Formats.USFMBible import USFMBible
 
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "createEmptyUSFMBooks( {}, {}, {} )".format( folderPath, currentBBB, requestDict ) )
+        vPrint( 'Quiet', debuggingThisModule, "createEmptyUSFMBooks( {}, {}, {} )".format( folderpath, currentBBB, requestDict ) )
 
 
     versificationObject = BibleVersificationSystem( requestDict['Versification'] ) \
                             if requestDict['Fill']=='Versification' else None
-    print( 'versificationObject', versificationObject )
+    vPrint( 'Quiet', debuggingThisModule, 'versificationObject', versificationObject )
     if versificationObject is not None:
         getNumChapters, getNumVerses = versificationObject.getNumChapters, versificationObject.getNumVerses
 
     if requestDict['Fill'] == 'Version':
         #ALL_CHAR_MARKERS = BibleOrgSysGlobals.loadedUSFMMarkers.getCharacterMarkersList( expandNumberableMarkers=True )
         uB = USFMBible( requestDict['Version'] ) # Get the Bible object
-        print( "Fill Bible1", uB )
+        vPrint( 'Quiet', debuggingThisModule, "Fill Bible1", uB )
         uB.preload()
-        print( "Fill Bible2", uB )
+        vPrint( 'Quiet', debuggingThisModule, "Fill Bible2", uB )
         #uB.loadBooks()
-        #print( "Fill Bible3", uB )
+        #vPrint( 'Quiet', debuggingThisModule, "Fill Bible3", uB )
 
     if requestDict['Books'] == 'None': booklist = []
     elif requestDict['Books'] == 'Current': booklist = [ currentBBB ]
@@ -164,18 +167,18 @@ def createEmptyUSFMBooks( folderPath, currentBBB, requestDict ):
             bookText = ''
             for verseDataEntry in uBB._processedLines:
                 pseudoMarker, cleanText = verseDataEntry.getMarker(), verseDataEntry.getCleanText()
-                #print( BBB, pseudoMarker, repr(cleanText) )
+                #vPrint( 'Quiet', debuggingThisModule, BBB, pseudoMarker, repr(cleanText) )
                 if '¬' in pseudoMarker or pseudoMarker in BOS_ALL_ADDED_MARKERS or pseudoMarker in ('c#','vp#',):
                     continue # Just ignore added markers -- not needed here
                 #if pseudoMarker in ('v','f','fr','x','xo',): # These fields should always end with a space but the processing will have removed them
                     #pseudoMarker += ' ' # Append a space since it didn't have one
                 #if pseudoMarker in ALL_CHAR_MARKERS: # Character markers to be closed
-                    #print( "CHAR MARKER" )
+                    #vPrint( 'Quiet', debuggingThisModule, "CHAR MARKER" )
                     #pass
                     ##if (USFM[-2]=='\\' or USFM[-3]=='\\') and USFM[-1]!=' ':
                     #if bookText[-1] != ' ':
                         #bookText += ' ' # Separate markers by a space e.g., \p\bk Revelation
-                        #if BibleOrgSysGlobals.debugFlag: print( "toUSFM: Added space to {!r} before {!r}".format( bookText[-2], pseudoMarker ) )
+                        #if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "toUSFM: Added space to {!r} before {!r}".format( bookText[-2], pseudoMarker ) )
                     #adjValue += '\\{}*'.format( pseudoMarker ) # Do a close marker
                 #elif pseudoMarker in ('f','x',): inField = pseudoMarker # Remember these so we can close them later
                 #elif pseudoMarker in ('fr','fq','ft','xo',): USFM += ' ' # These go on the same line just separated by spaces and don't get closed
@@ -184,16 +187,16 @@ def createEmptyUSFMBooks( folderPath, currentBBB, requestDict ):
                 elif pseudoMarker == 'c': bookText += '\\c {}'.format( cleanText )
                 elif pseudoMarker == 'v': bookText += '\\v {} '.format( cleanText )
                 else: bookText += '\\{} '.format( pseudoMarker )
-                #print( pseudoMarker, USFM[-200:] )
+                #vPrint( 'Quiet', debuggingThisModule, pseudoMarker, USFM[-200:] )
         else: halt # programming error
 
         # Write the actual file
         filename = '{}-{}.USFM'.format( USFMNumber, USFMAbbreviation )
-        with open( os.path.join( folderPath, filename ), mode='wt', encoding='utf-8' ) as theFile:
+        with open( os.path.join( folderpath, filename ), mode='wt', encoding='utf-8' ) as theFile:
             theFile.write( bookText )
         count += 1
-    print( len(skippedBooklist), "books skipped:", skippedBooklist ) # Should warn the user here
-    print( count, "books created" )
+    vPrint( 'Quiet', debuggingThisModule, len(skippedBooklist), "books skipped:", skippedBooklist ) # Should warn the user here
+    vPrint( 'Quiet', debuggingThisModule, count, "books created" )
 # end of BiblelatorHelpers.createEmptyUSFMBooks
 
 
@@ -204,7 +207,7 @@ def calculateTotalVersesForBook( BBB, getNumChapters, getNumVerses ):
     Returns the total number of verses in the book
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "calculateTotalVersesForBook( {} )".format( BBB ) )
+        vPrint( 'Quiet', debuggingThisModule, "calculateTotalVersesForBook( {} )".format( BBB ) )
     totalVerses = 0
     try:
         for C in range( 1, getNumChapters(BBB)+1 ):
@@ -223,7 +226,7 @@ def mapReferenceVerseKey( mainVerseKey ):
     Returns None if we don't have a mapping.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "mapReferenceVerseKey( {} )".format( mainVerseKey.getShortText() ) )
+        vPrint( 'Quiet', debuggingThisModule, "mapReferenceVerseKey( {} )".format( mainVerseKey.getShortText() ) )
 
     # A (temporary) dictionary containing NT references to OT
     REFERENCE_VERSE_KEY_DICT = {
@@ -233,7 +236,7 @@ def mapReferenceVerseKey( mainVerseKey ):
 
     if mainVerseKey in REFERENCE_VERSE_KEY_DICT:
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
+            vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
         return REFERENCE_VERSE_KEY_DICT[mainVerseKey]
 # end of BiblelatorHelpers.mapReferenceVerseKey
 
@@ -245,14 +248,14 @@ def mapParallelVerseKey( forGroupCode, mainVerseKey ):
     Returns None if we don't have a mapping.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "mapParallelVerseKey( {}, {} )".format( forGroupCode, mainVerseKey.getShortText() ) )
+        vPrint( 'Quiet', debuggingThisModule, "mapParallelVerseKey( {}, {} )".format( forGroupCode, mainVerseKey.getShortText() ) )
     groupIndex = BIBLE_GROUP_CODES.index( forGroupCode ) - 1
     parallelVerseKeyDict = {
         SimpleVerseKey('MAT','3','13'): (SimpleVerseKey('MRK','1','9'), SimpleVerseKey('LUK','3','21'), SimpleVerseKey('JHN','1','31') )
         }
     if mainVerseKey in parallelVerseKeyDict:
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( '  returning {}'.format( parallelVerseKeyDict[mainVerseKey][groupIndex].getShortText() ) )
+            vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( parallelVerseKeyDict[mainVerseKey][groupIndex].getShortText() ) )
         return parallelVerseKeyDict[mainVerseKey][groupIndex]
 # end of BiblelatorHelpers.mapParallelVerseKey
 
@@ -267,7 +270,7 @@ def mapReferencesVerseKey( mainVerseKey ):
     """
     global loadedReferences
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "mapReferencesVerseKey( {} )".format( mainVerseKey.getShortText() ) )
+        vPrint( 'Quiet', debuggingThisModule, "mapReferencesVerseKey( {} )".format( mainVerseKey.getShortText() ) )
     if loadedReferences is None:
         loadedReferences = BibleReferencesLinks()
         loadedReferences.loadData()
@@ -276,7 +279,7 @@ def mapReferencesVerseKey( mainVerseKey ):
     #    0: Link type ('QuotedOTReference','AlludedOTReference','PossibleOTReference')
     #    1: Link FlexibleVersesKey object
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "  mapReferencesVerseKey got result:", result )
+        vPrint( 'Quiet', debuggingThisModule, "  mapReferencesVerseKey got result:", result )
     resultList = []
     if result is not None:
         for linkType, link in result:
@@ -289,7 +292,7 @@ def mapReferencesVerseKey( mainVerseKey ):
             #}
         #if mainVerseKey in REFERENCE_VERSE_KEY_DICT:
             #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-                #print( '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
+                #vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
             #return REFERENCE_VERSE_KEY_DICT[mainVerseKey]
 # end of BiblelatorHelpers.mapReferencesVerseKey
 
@@ -308,7 +311,7 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
     If no sections are found, it goes a maximum of one chapter back or one chapter forward.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "findCurrentSection( {}, … )".format( currentVerseKey.getShortText() ) )
+        vPrint( 'Quiet', debuggingThisModule, "findCurrentSection( {}, … )".format( currentVerseKey.getShortText() ) )
 
     def sectionFoundIn( verseData ):
         """
@@ -316,22 +319,22 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
             returns True or False whether a section heading is found in it
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "sectionFoundIn( {!r} )".format( verseData ) )
+            vPrint( 'Quiet', debuggingThisModule, "sectionFoundIn( {!r} )".format( verseData ) )
 
         if verseData is None: return False
 
         elif isinstance( verseData, str ):
-            #print( "  It's a string!" )
+            #vPrint( 'Quiet', debuggingThisModule, "  It's a string!" )
             if '\\s ' in thisVerseData or '\\s1' in thisVerseData \
             or '\\s2' in thisVerseData or '\\s3' in thisVerseData:
                 return True
 
         elif isinstance( verseData, tuple ):
-            #print( "  It's an InternalBibleEntryList!" )
+            #vPrint( 'Quiet', debuggingThisModule, "  It's an InternalBibleEntryList!" )
             assert len(verseData) == 2
             verseDataList, context = verseData
-            #print( '   dataList', repr(verseDataList) )
-            #print( '    context', repr(context) )
+            #vPrint( 'Quiet', debuggingThisModule, '   dataList', repr(verseDataList) )
+            #vPrint( 'Quiet', debuggingThisModule, '    context', repr(context) )
             for verseDataEntry in verseDataList:
                 if isinstance( verseDataEntry, InternalBibleEntry ):
                     marker, cleanText = verseDataEntry.getMarker(), verseDataEntry.getCleanText()
@@ -352,8 +355,8 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
                 if marker in ( 's','s1','s2','s3','s4' ): return True
 
         else:
-            print( 'Ooops', repr(verseData) )
-            print( verseData.__type__ )
+            vPrint( 'Quiet', debuggingThisModule, 'Ooops', repr(verseData) )
+            vPrint( 'Quiet', debuggingThisModule, verseData.__type__ )
             halt # Programming error
 
         return False
@@ -362,12 +365,12 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
     # Start of main section of findCurrentSection
     BBB, C, V = currentVerseKey.getBCV()
     intC, intV = currentVerseKey.getChapterNumberInt(), currentVerseKey.getVerseNumberInt()
-    #print( 'fCS at', BBB, C, intC, V, intV )
+    #vPrint( 'Quiet', debuggingThisModule, 'fCS at', BBB, C, intC, V, intV )
 
     # First let's find the beginning of the section
     #  which could be in the current verse/chapter,
     #   or in the previous chapter (at most we assume)
-    #print( 'fCS finding start…' )
+    #vPrint( 'Quiet', debuggingThisModule, 'fCS finding start…' )
     firstC = max( intC-1, 0 )
     found = False
     for thisC in reversed( range( firstC, intC+1 ) ): # Look backwards
@@ -386,7 +389,7 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
 
     # Now let's find the end of the section
     #  which could be in the current chapter, or in the next chapter (at most we assume)
-    #print( 'fCS finding end…' )
+    #vPrint( 'Quiet', debuggingThisModule, 'fCS finding end…' )
     lastC = min( intC+1, getNumChapters( BBB ) )
     found = False
     for thisC in range( intC, lastC+1 ):
@@ -402,7 +405,7 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
         if found: break
     if not found: found = lastC, numVerses
     endKey = SimpleVerseKey( BBB, found[0], found[1] )
-    #print( "fCS returning", startKey.getShortText(), endKey.getShortText() )
+    #vPrint( 'Quiet', debuggingThisModule, "fCS returning", startKey.getShortText(), endKey.getShortText() )
     return startKey, endKey
 # end of BiblelatorHelpers.findCurrentSection
 
@@ -422,50 +425,52 @@ def handleInternalBibles( self, internalBible, controllingWindow ):
     """
     debuggingThisFunction = False
     if debuggingThisFunction or (BibleOrgSysGlobals.debugFlag and debuggingThisModule):
-        print( "handleInternalBibles( {}, {} )".format( internalBible, controllingWindow ) )
+        vPrint( 'Quiet', debuggingThisModule, "handleInternalBibles( {}, {} )".format( internalBible, controllingWindow ) )
         assert isinstance( internalBible, Bible )
         #self.setDebugText( "handleInternalBibles" )
-        #print( "hereHIB0", repr(internalBible), len(self.internalBibles) )
+        #vPrint( 'Quiet', debuggingThisModule, "hereHIB0", repr(internalBible), len(self.internalBibles) )
 
-    result = internalBible
+    result = internalBible # Default to returning what we were given
     if debuggingThisFunction and internalBible is None:
-        print( "  hIB: Got None" )
+        vPrint( 'Quiet', debuggingThisModule, "  hIB: Got None" )
     if internalBible is not None:
-        if debuggingThisFunction: print( "  hIB: Not None" )
+        if debuggingThisFunction: vPrint( 'Quiet', debuggingThisModule, "  hIB: Not None" )
         foundControllingWindowList = None
         for iB,cWs in self.internalBibles:
             # Some of these variables will be None but they'll still match
             #and internalBible.sourceFilepath == iB.sourceFilepath \ # PTX Bible sets sourceFilepath but others don't!
             if type(internalBible) is type(iB) \
-            and internalBible.abbreviation == iB.abbreviation \
-            and internalBible.name == iB.name \
-            and internalBible.sourceFilename == iB.sourceFilename \
+            and internalBible.abbreviation and internalBible.abbreviation == iB.abbreviation \
+            and internalBible.name and internalBible.name == iB.name \
+            and internalBible.sourceFilename and internalBible.sourceFilename == iB.sourceFilename \
             and internalBible.encoding == iB.encoding: # Let's assume they're the same
                 if internalBible.sourceFolder == iB.sourceFolder:
-                    if debuggingThisFunction: print( "  Got an IB match for {}!".format( iB.name ) )
+                    if debuggingThisFunction: vPrint( 'Quiet', debuggingThisModule, "  Got an IB match for {}!".format( iB.name ) )
                     result, foundControllingWindowList = iB, cWs
                     break
                 else:
                     if debuggingThisFunction:
-                        print( "handleInternalBibles: Got an almost IB match for {}!".format( iB.name ) )
-                        print( "    Source folders didn't match: {!r}\n           and {!r}".format( internalBible.sourceFolder, iB.sourceFolder ) )
+                        vPrint( 'Quiet', debuggingThisModule, "handleInternalBibles: Got an almost IB match for {}!".format( iB.name ) )
+                        vPrint( 'Quiet', debuggingThisModule, "    Source folders didn't match: {!r}\n           and {!r}".format( internalBible.sourceFolder, iB.sourceFolder ) )
                     result, foundControllingWindowList = iB, cWs
                     break
 
         if foundControllingWindowList is None: self.internalBibles.append( (internalBible,[controllingWindow]) )
         else: foundControllingWindowList.append( controllingWindow )
 
-    if debuggingThisModule or (BibleOrgSysGlobals.debugFlag and debuggingThisModule):
-        print( "Internal Bibles ({}) now:".format( len(self.internalBibles) ) )
+    if debuggingThisFunction or debuggingThisModule or (BibleOrgSysGlobals.debugFlag and debuggingThisModule):
+        vPrint( 'Quiet', debuggingThisModule, "Internal Bibles ({}) now:".format( len(self.internalBibles) ) )
         for something in self.internalBibles:
-            print( "  ", something )
-        print( self.internalBibles )
+            vPrint( 'Quiet', debuggingThisModule, "  ", something )
+        vPrint( 'Quiet', debuggingThisModule, self.internalBibles )
         for j,(iB,cWs) in enumerate( self.internalBibles ):
-            print( "  {}/ {} in {}".format( j+1, iB.getAName(), cWs ) )
-            print( "      {!r} {!r} {!r} {!r}".format( iB.name, iB.givenName, iB.shortName, iB.abbreviation ) )
-            print( "      {!r} {!r} {!r} {!r}".format( iB.sourceFolder, iB.sourceFilename, iB.sourceFilepath, iB.fileExtension ) )
-            print( "      {!r} {!r} {!r} {!r}".format( iB.status, iB.revision, iB.version, iB.encoding ) )
+            vPrint( 'Quiet', debuggingThisModule, "  {}/ {} in {}".format( j+1, iB.getAName(), cWs ) )
+            vPrint( 'Quiet', debuggingThisModule, "      {!r} {!r} {!r} {!r}".format( iB.name, iB.givenName, iB.shortName, iB.abbreviation ) )
+            vPrint( 'Quiet', debuggingThisModule, "      {!r} {!r} {!r} {!r}".format( iB.sourceFolder, iB.sourceFilename, iB.sourceFilepath, iB.fileExtension ) )
+            vPrint( 'Quiet', debuggingThisModule, "      {!r} {!r} {!r} {!r}".format( iB.status, iB.revision, iB.version, iB.encoding ) )
 
+    if debuggingThisModule or debuggingThisFunction:
+        vPrint( 'Quiet', debuggingThisModule, f"  handleInternalBibles is returning: {result}")
     return result
 # end of BiblelatorHelpers.handleInternalBibles
 
@@ -483,7 +488,7 @@ def logChangedFile( userName, loggingFolder, projectName, savedBBB, bookText ):
     Just logs some info about the recently changed book to a log file for the project.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #print( "logChangedFile( {}, {!r}, {}, {} )".format( loggingFolder, projectName, savedBBB, len(bookText) ) )
+        #vPrint( 'Quiet', debuggingThisModule, "logChangedFile( {}, {!r}, {}, {} )".format( loggingFolder, projectName, savedBBB, len(bookText) ) )
 
     filepath = getChangeLogFilepath( loggingFolder, projectName )
 
@@ -513,31 +518,31 @@ def parseEnteredBooknameField( bookNameEntry, currentBBB, CEntry, VEntry, BBBfun
     debuggingThisFunction = False
 
     if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        print( "parseEnteredBooknameField( {!r}, {}, {!r}, {!r}, … )" \
+        vPrint( 'Quiet', debuggingThisModule, "parseEnteredBooknameField( {!r}, {}, {!r}, {!r}, … )" \
                                 .format( bookNameEntry, currentBBB, CEntry, VEntry ) )
 
     # Do a bit of preliminary cleaning-up
     bookNameEntry = bookNameEntry.strip().replace( '  ', ' ' )
-    #print( "parseEnteredBooknameField: pulling apart {!r}".format( bookNameEntry ) )
+    #vPrint( 'Quiet', debuggingThisModule, "parseEnteredBooknameField: pulling apart {!r}".format( bookNameEntry ) )
 
     # Without the bookname (i.e., stay in current book)
     # Do these first because they are more strict (only digits and use re.fullmatch not re.search or re.match)
     match = re.fullmatch( '(\d{1,3})[:\. ](\d{1,3})', bookNameEntry ) # (Current book) C:V or C.V or C V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matched CV! {!r} {!r}".format( match.group(1), match.group(2) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matched CV! {!r} {!r}".format( match.group(1), match.group(2) ) )
         return currentBBB, match.group(1), match.group(2)
     match = re.fullmatch( '(\d{1,3})', bookNameEntry ) # (Current book) C
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matched C or V! {!r} as {!r} from {!r}".format( match.group(0), match.group(1), bookNameEntry ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matched C or V! {!r} as {!r} from {!r}".format( match.group(0), match.group(1), bookNameEntry ) )
         if BibleOrgSysGlobals.loadedBibleBooksCodes.isSingleChapterBook( currentBBB ): # take it as a V (not a C)
             return currentBBB, 1, match.group(1)
         return currentBBB, match.group(1), 1
     match = re.fullmatch( '[Vv:\.](\d{1,3})', bookNameEntry ) # (Current book) V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedV! {!r}".format( match.group(1) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedV! {!r}".format( match.group(1) ) )
         return currentBBB, CEntry, match.group(1)
 
     # With a BBB first on the line
@@ -545,21 +550,21 @@ def parseEnteredBooknameField( bookNameEntry, currentBBB, CEntry, VEntry, BBBfun
     match = re.fullmatch( BBB_RE + '[ ]{0,1}(\d{1,3})[:\. ](\d{1,3})', uppercaseBookNameEntry ) # bookname C:V or C.V or C V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedBBBCV! {!r} {!r} {!r}".format( match.group(1), match.group(2), match.group(3) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedBBBCV! {!r} {!r} {!r}".format( match.group(1), match.group(2), match.group(3) ) )
         newBBB = match.group(1)
         if BibleOrgSysGlobals.loadedBibleBooksCodes.isValidBBB( newBBB ): # confirm that it's a BBB
             return newBBB, match.group(2), match.group(3)
     match = re.fullmatch( BBB_RE + '[ ]{0,1}[Vv:\.](\d{1,3})', uppercaseBookNameEntry ) # bookname (single chapter book) V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedBBBV! {!r} {!r} (for chapter {!r})".format( match.group(1), match.group(2), CEntry ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedBBBV! {!r} {!r} (for chapter {!r})".format( match.group(1), match.group(2), CEntry ) )
         newBBB = match.group(1)
         if BibleOrgSysGlobals.loadedBibleBooksCodes.isValidBBB( newBBB ): # confirm that it's a BBB
             return newBBB, CEntry, match.group(2)
     match = re.fullmatch( BBB_RE + '[ ]{0,1}(\d{1,3})', uppercaseBookNameEntry ) # bookname C (or single chapter book with V)
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedBBB C or V! {!r} {!r}".format( match.group(1), match.group(2) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedBBB C or V! {!r} {!r}".format( match.group(1), match.group(2) ) )
         newBBB = match.group(1)
         if BibleOrgSysGlobals.loadedBibleBooksCodes.isValidBBB( newBBB ): # confirm that it's a BBB
             if BibleOrgSysGlobals.loadedBibleBooksCodes.isSingleChapterBook( newBBB ): # take it as a V (not a C)
@@ -570,18 +575,18 @@ def parseEnteredBooknameField( bookNameEntry, currentBBB, CEntry, VEntry, BBBfun
     match = re.fullmatch( '([123]{0,1}?\D+?)[ ]{0,1}(\d{1,3})[:\. ](\d{1,3})', bookNameEntry ) # bookname C:V or C.V or C V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedBCV! {!r} {!r} {!r}".format( match.group(1), match.group(2), match.group(3) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedBCV! {!r} {!r} {!r}".format( match.group(1), match.group(2), match.group(3) ) )
         return BBBfunction( match.group(1) ), match.group(2), match.group(3)
     match = re.fullmatch( '([123]{0,1}?\D+?)[ ]{0,1}[Vv:\.](\d{1,3})', bookNameEntry ) # bookname (single chapter book) V
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedBV! {!r} {!r} (for chapter {!r})".format( match.group(1), match.group(2), CEntry ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedBV! {!r} {!r} (for chapter {!r})".format( match.group(1), match.group(2), CEntry ) )
         newBBB = BBBfunction( match.group(1) )
         return newBBB, CEntry, match.group(2)
     match = re.fullmatch( '([123]{0,1}?\D+?)[ ]{0,1}(\d{1,3})', bookNameEntry ) # bookname C (or single chapter book with V)
     if match:
         if debuggingThisFunction or BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            print( "  matchedB C or V! {!r} {!r}".format( match.group(1), match.group(2) ) )
+            vPrint( 'Quiet', debuggingThisModule, "  matchedB C or V! {!r} {!r}".format( match.group(1), match.group(2) ) )
         newBBB = BBBfunction( match.group(1) )
         if BibleOrgSysGlobals.loadedBibleBooksCodes.isSingleChapterBook( newBBB ): # take it as a V (not a C)
             return newBBB, 1, match.group(2)
@@ -596,31 +601,57 @@ def parseEnteredBooknameField( bookNameEntry, currentBBB, CEntry, VEntry, BBBfun
 
 
 
-def demo() -> None:
+def briefDemo() -> None:
     """
     Main program to handle command line parameters and then run what they want.
     """
     from tkinter import Tk
 
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: print( "Running demo…" )
+    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = Tk()
     tkRootWindow.title( programNameVersion )
 
     #swnd = SaveWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test SWND" )
-    #print( "swndResult", swnd.result )
+    #vPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
     #dwnd = DeleteWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test DWND" )
-    #print( "dwndResult", dwnd.result )
+    #vPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
     #srb = SelectResourceBox( tkRootWindow, [(x,y) for x,y, in {"ESV":"ENGESV","WEB":"ENGWEB","MS":"MBTWBT"}.items()], "Test SRB" )
-    #print( "srbResult", srb.result )
+    #vPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
 
-    #tkRootWindow.quit()
+    # Program a shutdown
+    tkRootWindow.after( 2_000, tkRootWindow.destroy ) # Destroy the widget after 2 seconds
 
     # Start the program running
     #tkRootWindow.mainloop()
-# end of BiblelatorHelpers.demo
+# end of BiblelatorHelpers.briefDemo
 
+def fullDemo() -> None:
+    """
+    Full demo to check class is working
+    """
+    from tkinter import Tk
+
+    BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
+    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+
+    tkRootWindow = Tk()
+    tkRootWindow.title( programNameVersion )
+
+    #swnd = SaveWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test SWND" )
+    #vPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
+    #dwnd = DeleteWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test DWND" )
+    #vPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
+    #srb = SelectResourceBox( tkRootWindow, [(x,y) for x,y, in {"ESV":"ENGESV","WEB":"ENGWEB","MS":"MBTWBT"}.items()], "Test SRB" )
+    #vPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
+
+    # Program a shutdown
+    tkRootWindow.after( 30_000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+
+    # Start the program running
+    #tkRootWindow.mainloop()
+# end of BiblelatorHelpers.fullDemo
 
 if __name__ == '__main__':
     from multiprocessing import freeze_support
@@ -630,7 +661,7 @@ if __name__ == '__main__':
     parser = BibleOrgSysGlobals.setup( SHORT_PROGRAM_NAME, PROGRAM_VERSION, LAST_MODIFIED_DATE )
     BibleOrgSysGlobals.addStandardOptionsAndProcess( parser )
 
-    demo()
+    fullDemo()
 
     BibleOrgSysGlobals.closedown( PROGRAM_NAME, PROGRAM_VERSION )
 # end of BiblelatorHelpers.py
