@@ -396,9 +396,9 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                             rw.openBox( boxType, boxSource )
 
             elif windowType == 'TSVBibleEditWindow':
-                try: filepath = convertToPython( thisStuff['TSVTablePath'] )
-                except KeyError: filepath = None
-                rw = self.openFileTSVEditWindow( filepath, windowGeometry )
+                try: folderpath = convertToPython( thisStuff['TSVFolderPath'] )
+                except KeyError: folderpath = None
+                rw = self.openTSVEditWindow( folderpath, windowGeometry )
 
             elif windowType == 'BibleReferenceCollectionWindow':
                 xyz = "JustTesting!"
@@ -520,7 +520,7 @@ def getCurrentChildWindowSettings( self ):
             thisOne['BibleFolderPath'] = appWin.moduleID
 
         elif appWin.windowType == 'TSVBibleEditWindow':
-            thisOne['TSVTablePath'] = appWin.filepath
+            thisOne['TSVFolderPath'] = appWin.folderpath
 
         elif appWin.windowType == 'BibleLexiconResourceWindow':
             thisOne['BibleLexiconPath'] = appWin.moduleID
